from flask import Flask, flash, request, redirect, url_for, stream_with_context, Response, send_file
from cloudinary.uploader import upload
from cloudinary.utils import cloudinary_url
import cloudinary as Cloud
import RPi.GPIO as GPIO
import time
import sys, os
import picamera
import thread
import ConfigParser

GPIO.setmode(GPIO.BCM)
GPIO.setwarnings(False)

led_pin = 12

GPIO.setup(led_pin, GPIO.OUT)
GPIO.output(led_pin, GPIO.HIGH)

app = Flask(__name__)

#Setup Cloudinary
config = ConfigParser.ConfigParser()
config.read('/home/pi/TabForPets/config.ini')
Cloud.config(
    cloud_name = config.get('DEFAULT','CLOUD_NAME'),
    api_key= config.get('DEFAULT','API_KEY'),
    api_secret= config.get('DEFAULT','API_SECRET')
)

def setAngle(angle,p):
    duty = angle / 10 + 2.5
    p.ChangeDutyCycle(duty)
    time.sleep(1)
	
def servoMotor():
    GPIO.setwarnings(False)
    GPIO.setup(18,GPIO.OUT)
    try:
        p = GPIO.PWM(18, 100)
        p.start(5)
        setAngle(160,p)
        p.stop()
    except RuntimeError:
        pass
    return

def ultrasonicMeasurement():
    GPIO_SIG = 23
    GPIO.setup(GPIO_SIG, GPIO.OUT)
    GPIO.output(GPIO_SIG, GPIO.LOW)
    time.sleep(0.2)
    GPIO.output(GPIO_SIG, GPIO.HIGH)
    time.sleep(0.5)
    GPIO.output(GPIO_SIG, GPIO.LOW)
    start = time.time()
    
    GPIO.setup(GPIO_SIG, GPIO.IN)
    try:
        while GPIO.input(GPIO_SIG) == 0:
            start = time.time()
        
        while GPIO.input(GPIO_SIG) == 1:
            stop = time.time()
    except RuntimeError:
        pass
    return measurementPulse(start,stop)

def measurementPulse(start,stop):
    elapsed = stop - start
    distance = elapsed * 34300 #Multiplied by speed of sound
    distance = distance / 2
    return distance

def setupCam():
    camera = picamera.PiCamera()
    camera.hflip = True
    camera.vflip = True
    return camera

    
def camTakeVid(camera):
    dureeVideo = 5
    nomVideo = "/home/pi/TabForPets/videoChat"
    camera.start_recording(nomVideo+".h264")
    print("REC...")
    time.sleep(dureeVideo)
    camera.stop_recording()
    
    #Conversion en MP4
    commande = "MP4Box -add "+nomVideo+".h264 " + nomVideo+".mp4"
    output = os.system(commande)
    
def postVid():
    #On supprime la precedente video avant d'enregister la nouvelle sinon pas de nouvelle video
    try:
        os.remove("/home/pi/TabForPets/videoChat.mp4")
        os.remove("/home/pi/TabForPets/videoChat.h264")
    except OSError:
        pass
    camera = setupCam()
    camTakeVid(camera)
    camera.close()
    testvid = upload("/home/pi/TabForPets/videoChat.mp4", resource_type = "video") #Upload to Cloudinary
        

def activationCamera():
    #Le capteur detecte les presences en permanence
    while(1):
        distance = ultrasonicMeasurement()
        if distance < 10.0:
            postVid()


@app.route("/")
def hello():
    return "Hello World!"

#Fonction de callback lorsque le serveur recoit la requete POST
@app.route("/post",methods=['POST'])
def postReq():
    servoMotor()
    return '',204

thread.start_new_thread(activationCamera,())
thread.start_new_thread(app.run,())


